@@ -618,8 +618,10 @@ def savediv_(*args):
     denominator = parseExpression(args[1])
     onzero = None if len(args) ==2 else parseExpression(args[2])
 
-    return '0' if onzero is None else str(onzero) + ' if ' + denominator + ' == 0 else ' + nominator + ' / ' + denominator
-
+    if onzero:
+        return "( "+ str(onzero) + ")" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(denominator) + ")"
+    else:
+        return '(' + str(nominator) + ' / ' + str(denominator) + ")"
 def history_(*args):
     args = remove_nesting(args)
 
@@ -868,6 +870,8 @@ builtins = {
 
     'savediv': lambda *args: savediv_(args),
 
+    'safediv': lambda *args: savediv_(args),
+
     'step': lambda *args: step_(args),
 
     'rootn' : lambda *args: "( self.rootn({}, {}) )".format(parseExpression(remove_nesting(args)[0]) ,parseExpression(remove_nesting(args)[1] )),
